import { injectable, inject } from "inversify";
import { CommandContribution, CommandRegistry, MenuContribution, MenuModelRegistry, MessageService } from "@theia/core/lib/common";
import { TerminalService } from '@theia/terminal/lib/browser/base/terminal-service';
import { TerminalWidget } from '@theia/terminal/lib/browser/base/terminal-widget';
import { TerminalWidgetFactoryOptions } from '@theia/terminal/lib/browser/terminal-widget-impl';
import { CommonMenus } from "@theia/core/lib/browser";
import { MAIN_MENU_BAR } from '@theia/core';

export const NpmstartExtensionCommand = {
    id: 'NpmstartExtension.command',
    label: "Shows a message"
};


export namespace RunMenus {
    export const RUN = [...MAIN_MENU_BAR, '7_run'];
    export const RUN_NEW = [...RUN, '1_run'];
    export const RUN_TASKS = [...RUN, '2_run'];
   
}
@injectable()
export class NpmstartExtensionCommandContribution implements CommandContribution {

    constructor(
        @inject(MessageService) private readonly messageService: MessageService,
		@inject(TerminalService) protected readonly terminalService: TerminalService,
    ) { }

    registerCommands(registry: CommandRegistry): void {
        registry.registerCommand(NpmstartExtensionCommand, {
            execute: () => {
				this.messageService.info('Running...');
                this.runSelectedText();
			}
        });
    }
	
	 async runSelectedText(): Promise<void> {
					    let terminal = this.terminalService.currentTerminal;
				if (!terminal) {
					terminal = <TerminalWidget>await this.terminalService.newTerminal(<TerminalWidgetFactoryOptions>{ created: new Date().toString() });
					await terminal.start();
					this.terminalService.activateTerminal(terminal);
				}
				terminal.sendText("npm start\n");  
		 
	 }
	 
}

@injectable()
export class NpmstartExtensionMenuContribution implements MenuContribution {
	


    registerMenus(menus: MenuModelRegistry): void {
		
		        menus.registerSubmenu(RunMenus.RUN, 'Run');
        menus.registerMenuAction(RunMenus.RUN_NEW, {
            commandId: NpmstartExtensionCommand.id,
            label: 'Run (npm start)',
            order: '0'
        });	
		
		
        menus.registerMenuAction(CommonMenus.EDIT_FIND, {
            commandId: NpmstartExtensionCommand.id,
            label: 'Run (npm start)'
        });
    }
}